import vl from 'vega-lite-api';
import { range, hcl } from 'd3';

const numHues = 9;
const colorScale = {
  range: range(numHues).map(i => hcl((i / numHues) * 360, 80, 90).hex())
};

export const viz = () =>
  vl
    .markLine({ size: 0.2 })
    .data(
      'https://raw.githubusercontent.com/vega/vega-datasets/master/data/zipcodes.csv'
    )
    .transform(
      vl.calculate('substring(datum.zip_code, 0, 3)').as('digit'),
      vl.filter(`
      datum.state != "MH" &&
      datum.state !== "MP" &&
      datum.state !== "FM" &&
      datum.state !== "FM" &&
      datum.state !== "PU" &&
      datum.state !== "PW" &&
      datum.state !== "PR" &&
      datum.state !== "VI" &&
      datum.state !== "HI" &&
      datum.state !== "AS" &&
      datum.state !== "GU"
    `)
    )
    .project(vl.projection('albersUsa'))
    .encode(
      vl.longitude().fieldQ('longitude'),
      vl.latitude().fieldQ('latitude'),
      vl
        .color()
        .fieldN('digit')
        .legend(null)
        .scale(colorScale),
      vl.tooltip('city')
    )
    .width(960)
    .height(500)
    .padding(0)
    .autosize({ type: 'fit-x', contains: 'padding' })
    .config({ view: { stroke: null } });
